Index: /trunk/include/iprt/cpp/ministring.h
===================================================================
--- /trunk/include/iprt/cpp/ministring.h	(revision 52579)
+++ /trunk/include/iprt/cpp/ministring.h	(revision 52580)
@@ -33,5 +33,4 @@
 
 #include <new>
-#include <algorithm>
 
 
@@ -880,12 +879,22 @@
     /**
      * Swaps two strings in a fast way.
+     *
      * Exception safe.
      * 
-     * @param   that  the string to swap for */
-    inline void swap(RTCString &that) throw()
-    {
-        std::swap(m_psz, that.m_psz);
-        std::swap(m_cch, that.m_cch);
-        std::swap(m_cbAllocated, that.m_cbAllocated);
+     * @param   a_rThat  The string to swap with.
+     */
+    inline void swap(RTCString &a_rThat) throw()
+    {
+        char   *pszTmp         = m_psz;
+        size_t  cchTmp         = m_cch;
+        size_t  cbAllocatedTmp = m_cbAllocated;
+
+        m_psz                  = a_rThat.m_psz;
+        m_cch                  = a_rThat.m_cch;
+        m_cbAllocated          = a_rThat.m_cbAllocated;
+
+        a_rThat.m_psz          = pszTmp;
+        a_rThat.m_cch          = cchTmp;
+        a_rThat.m_cbAllocated  = cbAllocatedTmp;
     }
 
